diff --git a/src/wp-admin/includes/misc.php b/src/wp-admin/includes/misc.php
index 61d7698310..6bd2c61fd9 100644
--- a/src/wp-admin/includes/misc.php
+++ b/src/wp-admin/includes/misc.php
@@ -1353,12 +1353,14 @@ function update_option_new_admin_email( $old_value, $value ) {
 
 	$switched_locale = switch_to_locale( get_user_locale() );
 
 	/* translators: Do not translate USERNAME, ADMIN_URL, EMAIL, SITENAME, SITEURL: those are placeholders. */
 	$email_text = __(
-		'Howdy ###USERNAME###,
+		'Howdy,
 
-You recently requested to have the administration email address on
-your site changed.
+The user \'###USERNAME###\' recently requested to have the administration
+email address on your site changed to ###NEW_EMAIL###.
+
+The previous email address is ###OLD_EMAIL###.
 
 If this is correct, please click on the following link to change it:
 ###ADMIN_URL###
@@ -1366,8 +1368,6 @@ If this is correct, please click on the following link to change it:
 You can safely ignore and delete this email if you do not want to
 take this action.
 
-This email has been sent to ###EMAIL###
-
 Regards,
 All at ###SITENAME###
 ###SITEURL###'
@@ -1379,7 +1379,8 @@ All at ###SITENAME###
 	 * The following strings have a special meaning and will get replaced dynamically:
 	 * ###USERNAME###  The current user's username.
 	 * ###ADMIN_URL### The link to click on to confirm the email change.
 	 * ###EMAIL###     The proposed new site admin email address.
 	 * ###SITENAME###  The name of the site.
 	 * ###SITEURL###   The URL to the site.
 	 *
@@ -1399,7 +1400,8 @@ All at ###SITENAME###
 	$current_user = wp_get_current_user();
 	$content      = str_replace( '###USERNAME###', $current_user->user_login, $content );
 	$content      = str_replace( '###ADMIN_URL###', esc_url( self_admin_url( 'options.php?adminhash=' . $hash ) ), $content );
-	$content      = str_replace( '###EMAIL###', $value, $content );
+	$content      = str_replace( '###OLD_EMAIL###', $old_value, $content );
+	$content      = str_replace( '###NEW_EMAIL###', $value, $content );
 	$content      = str_replace( '###SITENAME###', wp_specialchars_decode( get_option( 'blogname' ), ENT_QUOTES ), $content );
 	$content      = str_replace( '###SITEURL###', home_url(), $content );
 
@@ -1353,12 +1353,14 @@ function update_option_new_admin_email( $old_value, $value ) {
 	$switched_locale = switch_to_locale( get_user_locale() );
 
-	/* translators: Do not translate USERNAME, ADMIN_URL, EMAIL, SITENAME, SITEURL: those are placeholders. */
+	/* translators: Do not translate USERNAME, ADMIN_URL, OLD_EMAIL, NEW_EMAIL, SITENAME, SITEURL: those are placeholders. */
 	$email_text = __(
@@ -1379,7 +1379,8 @@ All at ###SITENAME###
 	 * ###USERNAME###  The current user's username.
 	 * ###ADMIN_URL### The link to click on to confirm the email change.
-	 * ###EMAIL###     The proposed new site admin email address.
+	 * ###OLD_EMAIL### The old site admin email address.
+	 * ###NEW_EMAIL### The proposed new site admin email address.
 	 * ###SITENAME###  The name of the site.
 	 * ###SITEURL###   The URL to the site.
